@@ -242,7 +242,7 @@ class _Music(DataObject, Music163Comment):
         self, 
         br: Union[int, str] = 999000,
         download_path: str = None
-    ) -> Union[str, dict[str, Any]]:
+    ) -> str:
         """获取播放该 music 对象指定的歌曲文件"""
         data = await self._play_url(br)
         if data["code"] != 200:
@@ -254,7 +254,7 @@ class _Music(DataObject, Music163Comment):
         self, 
         br: Union[int, str] = 999000,
         download_path: str = None
-    ) -> Union[str, dict[str, Any]]:
+    ) -> str:
         """获取下载该 music 对象指定的歌曲文件"""
         data = await self._download_url(br)
         if data["code"] != 200:
@@ -264,13 +264,13 @@ class _Music(DataObject, Music163Comment):
 
         return await _download(data["data"]["url"], f"{self.id}.mp3", download_path)
 
-    async def album(self) -> Union["Album", dict[str, Any]]:
+    async def album(self) -> "Album":
         """实例化该对像专辑 album 对像并返回 album 对像"""
         from pycloudmusic.music163 import Music163Api
         
         return await Music163Api().album(self.album_data["id"])
 
-    async def mv(self) -> Union["Mv", dict[str, Any]]:
+    async def mv(self) -> "Mv":
         """获取该对像 mv 实例化 mv 对像并返回 mv 对像"""
         from pycloudmusic.music163 import Music163Api
 
@@ -561,7 +561,7 @@ class User(Api):
     async def record(
         self, 
         type_: bool = True
-    ) -> Union[Generator[Music, None, None], dict[str, Any]]:
+    ) -> Generator[Music, None, None]:
         """获取该对象听歌榜单"""
         data = await _post("/api/v1/play/record", {
             "uid": self.id, "type": 0 if type_ else 1
@@ -692,7 +692,7 @@ class _Mv(DataObject, Music163Comment):
         self, 
         download_path: Optional[str] = None, 
         quality: Union[str, int] = 1080
-    ) -> Union[str, dict[str, Any]]:
+    ) -> str:
         """获取播放该 mv 对象指定的视频文件"""
         return await _download((await self._play_url(quality))["data"]["url"], f"{self.id}.mp4", download_path)
 
@@ -780,7 +780,7 @@ class _Artist(DataObject):
         hot: bool = True, 
         page: int = 0, 
         limit: int = 100
-    ) -> Union[Generator[Music, None, None], dict[str, Any]]:
+    ) -> Generator[Music, None, None]:
         """获取该对像歌曲"""
         return (Music(music_data) for music_data in (await _post("/api/v1/artist/songs", {
             "id": self.id,
@@ -791,7 +791,7 @@ class _Artist(DataObject):
             "work_type": 1
         }))['songs'])
 
-    async def song_top(self) -> Union[Generator[Music, None, None], dict[str, Any]]:
+    async def song_top(self) -> Generator[Music, None, None]:
         """获取该对像热门50首"""
         return (Music(music_data) for music_data in (await _post("/api/artist/top/song", {
             "id": self.id
@@ -801,7 +801,7 @@ class _Artist(DataObject):
         self, 
         page: int = 0,
         limit: int = 30
-    ) -> Union[Generator[Album, None, None], dict[str, Any]]:
+    ) -> Generator[Album, None, None]:
         """获取该对像专辑"""
         return (Album(album_data) for album_data in (await _post("/api/artist/albums/%s" % self.id, {
             "limit": limit, "offset": limit * page, "total": True,
@@ -1429,11 +1429,11 @@ class My(User):
             "type": 0 if type_ else 1
         })
 
-    async def recommend_songs(self) -> Union[Generator[Music, None, None], dict[str, Any]]:
+    async def recommend_songs(self) -> Generator[Music, None, None]:
         """获取日推"""
         return (Music(music_data) for music_data in (await _post("/api/v3/discovery/recommend/songs"))["data"]["dailySongs"])
 
-    async def recommend_resource(self) -> Union[Generator[ShortPlayList, None, None], dict[str, Any]]:
+    async def recommend_resource(self) -> Generator[ShortPlayList, None, None]:
         """获取每日推荐歌单"""
         return (ShortPlayList(playlist_data) for playlist_data in ( await _post("/api/v1/discovery/recommend/resource"))["recommend"])
 
@@ -1442,7 +1442,7 @@ class My(User):
         music_id: Union[str, int], 
         sid: Optional[Union[str, int]] = None, 
         playlist_id: Optional[Union[str, int]] = None
-    ) -> Union[Generator[Music, None, None], dict[str, Any]]:
+    ) -> Generator[Music, None, None]:
         """心动模式/智能播放"""
         if playlist_id is None:
             playlist_id = await self._get_like_playlist_id()
@@ -1459,7 +1459,7 @@ class My(User):
         self, 
         page: int = 0, 
         limit: int = 25
-    ) -> Union[tuple[int, Generator[ShortArtist, None, None]], dict[str, Any]]:
+    ) -> tuple[int, Generator[ShortArtist, None, None]]:
         """查看 cookie 用户收藏的歌手"""
         data = await _post("/api/artist/sublist", {
             "limit": limit, 
@@ -1473,7 +1473,7 @@ class My(User):
         self, 
         page: int = 0, 
         limit: int = 25
-    ) -> Union[tuple[int, Generator[ShortAlbum, None, None]], dict[str, Any]]:
+    ) -> tuple[int, Generator[ShortAlbum, None, None]]:
         """查看 cookie 用户收藏的专辑"""
         data = await _post("/api/album/sublist", {
             "limit": limit, 
@@ -1487,7 +1487,7 @@ class My(User):
         self, 
         page: int = 0, 
         limit: int = 25
-    ) -> Union[tuple[int, Generator[ShortDj, None, None]], dict[str, Any]]:
+    ) -> tuple[int, Generator[ShortDj, None, None]]:
         """查看 cookie 用户收藏的电台"""
         data = await _post("/api/djradio/get/subed", {
             "limit": limit, 
@@ -1501,7 +1501,7 @@ class My(User):
         self, 
         page: int = 0, 
         limit: int = 25
-    ) -> Union[tuple[int, Generator[ShortMv, None, None]], dict[str, Any]]:
+    ) -> tuple[int, Generator[ShortMv, None, None]]:
         """查看 cookie 用户收藏的 MV"""
         data = await _post("/api/cloudvideo/allvideo/sublist", {
             "limit": limit, 
@@ -1539,7 +1539,7 @@ class My(User):
         self, 
         page: int = 0, 
         limit: int = 30
-    ) -> Union[Cloud, dict[str, Any]]:
+    ) -> Cloud:
         """获取云盘数据并实例化一个 cloud 对象返回"""
 
         return Cloud(await _post("/api/v1/cloud/get", {
